@@ -46,14 +46,14 @@ vmesh (z);
 
 printf ("Press a key.\n"); pause;
 
-printf (["The same surface, with checkered stripes ",\
+printf (["The same surface, with checkered stripes ",...
 	 "(see the 'checker' option).\n"]);
 
 vmesh (z,"checker",-[6,5]);
 
 printf ("Press a key.\n"); pause;
 
-printf (["The same surface, with z-dependent coloring (see 'zrb', 'zgrey'\n",\
+printf (["The same surface, with z-dependent coloring (see 'zrb', 'zgrey'\n",...
 	 "  and 'zcol' options)\n"]);
 
 vmesh (z,"zrb");
