@@ -108,7 +108,7 @@ surf_args = {x,y,z};	# Arguments that'll be passed to vrml_surf
 
 if numel (varargin)
 
-  op1 = [" tran col checker creaseAngle emit colorPerVertex tex zcol  frame ",\
+  op1 = [" tran col checker creaseAngle emit colorPerVertex tex zcol  frame ",...
 	 " level lcol ltran bwid "];
   op0 = " smooth zgray zrb normalize steps bars ";
 
@@ -120,8 +120,8 @@ if numel (varargin)
 #   all_surf_opts  = list ("tran", "col", "checker", "creaseAngle", "emit", \
 # 			 "colorPerVertex", "smooth", "tex",\
 # 			 "zgray","zrb","zcol");
-  all_surf_opts  = {"tran", "col", "checker", "creaseAngle", "emit", \
-		    "colorPerVertex", "smooth", "steps", "bars", "bwid", "tex",\
+  all_surf_opts  = {"tran", "col", "checker", "creaseAngle", "emit", ...
+		    "colorPerVertex", "smooth", "steps", "bars", "bwid", "tex",...
 		    "zgray","zrb","zcol"};
 
   for i = 1:length(all_surf_opts)
@@ -187,10 +187,10 @@ pt2 = pts(:,ii); x2 = x(ii); y2 = y(ii); z2 = z(ii);
 
 # pl = [pl1 pl2];
 
-pl = [vrml_DirectionalLight("direction",[-1,-1,-1],"intensity",0.75),\
-      vrml_DirectionalLight("direction",[-1, 1,-1],"intensity",0.5),\
-      vrml_DirectionalLight("direction",[ 1,-1,-1],"intensity",0.5),\
-      vrml_DirectionalLight("direction",[ 1, 1,-1],"intensity",0.33),\
+pl = [vrml_DirectionalLight("direction",[-1,-1,-1],"intensity",0.75),...
+      vrml_DirectionalLight("direction",[-1, 1,-1],"intensity",0.5),...
+      vrml_DirectionalLight("direction",[ 1,-1,-1],"intensity",0.5),...
+      vrml_DirectionalLight("direction",[ 1, 1,-1],"intensity",0.33),...
       vrml_DirectionalLight("direction",[ 0, 0, 1],"intensity",0.5)];
 
 #  distance = max ([max (x(:)) - min (x(:)),\
@@ -205,7 +205,7 @@ medpts = (minpts + maxpts)/2;
 ptssz  = (maxpts - minpts);
 ptssz  = max (ptssz, max (ptssz/10));
 
-if frame, fr = vrml_frame (minpts-ptssz/10,\
+if frame, fr = vrml_frame (minpts-ptssz/10,...
 			   "scale", ptssz * 1.2, "col",(ones(3)+eye(3))/2);
 else      fr = "";
 end
@@ -235,10 +235,10 @@ if ! isempty (level)
   if prod (size (ltran)) == 1    , ltran = ltran*ones(1,nlev); end
   
   for i = 1:nlev
-    slevel = [slevel, \
-	      vrml_parallelogram([xmin     xmin     xmax     xmax;\
-				  ymin     ymax     ymax     ymin;\
-				  level(i) level(i) level(i) level(i)],\
+    slevel = [slevel, ...
+	      vrml_parallelogram([xmin     xmin     xmax     xmax;...
+				  ymin     ymax     ymax     ymin;...
+				  level(i) level(i) level(i) level(i)],...
 				 "col",lcol(i,:),"tran",ltran(i))];
   end
 end
