@@ -48,7 +48,7 @@ if nargin > 1
   op1 = " rad tran col hcol brad emit " ;
   op0 = " verbose balls noemit arrow " ;
 
-  df = tars (rad, tran, col, hcol, verbose, balls, noemit, arrow, brad, \
+  df = tars (rad, tran, col, hcol, verbose, balls, noemit, arrow, brad, ...
 	    emit);
 
 
@@ -97,36 +97,36 @@ for i = 2:N
 
       smat = vrml_material (col(:,i-1), emitcol(:,i-1), tran(i-1));
 				# Do a cylinder
-      s = [s,sprintf(["Transform {\n",\
-		      "  translation %8.3f %8.3f %8.3f\n",\
-		      "  children [\n",\
-		      "    Transform {\n",\
-		      "      rotation    %8.3f %8.3f %8.3f %8.3f\n",\
-		      "      children [\n",\
-		      "        Shape {\n",\
-		      "          appearance Appearance {\n",\
-		      "              %s",\
-		      "          }\n",\
-		      "          geometry Cylinder {\n",\
-		      "            height %8.3f\n",\
-		      "            radius %8.3f\n",\
-		      "          }\n",\
-		      "        }\n",\
-		      "      ]\n",\
-		      "    }\n",\
-		      "  ]\n",\
-		      "}\n"],\
-		     t,\
-		     ax,an,\
-		     smat,\
-		     n,\
+      s = [s,sprintf(["Transform {\n",...
+		      "  translation %8.3f %8.3f %8.3f\n",...
+		      "  children [\n",...
+		      "    Transform {\n",...
+		      "      rotation    %8.3f %8.3f %8.3f %8.3f\n",...
+		      "      children [\n",...
+		      "        Shape {\n",...
+		      "          appearance Appearance {\n",...
+		      "              %s",...
+		      "          }\n",...
+		      "          geometry Cylinder {\n",...
+		      "            height %8.3f\n",...
+		      "            radius %8.3f\n",...
+		      "          }\n",...
+		      "        }\n",...
+		      "      ]\n",...
+		      "    }\n",...
+		      "  ]\n",...
+		      "}\n"],...
+		     t,...
+		     ax,an,...
+		     smat,...
+		     n,...
 		     rad)];
     else
       t = x(:,i-1) ;
       if isnan (hcol), hcol = col(:,i); end
       arrowcol = [col(:,i) hcol(1:3)(:)];
-      s = [s,\
-	   vrml_transfo(vrml_arrow ([n,nan,2*rad/n,rad/n],arrowcol,emit),\
+      s = [s,...
+	   vrml_transfo(vrml_arrow ([n,nan,2*rad/n,rad/n],arrowcol,emit),...
 		        t, ax*an)];
     end
   end
@@ -137,7 +137,7 @@ if balls,
   s = [s, vrml_points(x,"balls","col",col, "rad",brad,"emit",emit)];
 elseif columns(x)>2,
 				# Make a rounded junction
-  s = [s, vrml_points(x(:,2:columns(x)-1),"balls","col",col,"rad",rad, \
+  s = [s, vrml_points(x(:,2:columns(x)-1),"balls","col",col,"rad",rad, ...
 		      "emit", emit)];
 end
 
