@@ -13,19 +13,19 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
-printf (["\n",\
-	 "    VRML Mini-HOWTO's first listing\n",\
+printf (["\n",...
+	 "    VRML Mini-HOWTO's first listing\n",...
 	 "    Display a quadratic surface w/ 31 x 31 points\n\n"]);
 
-printf (["    Reminder of FreeWRL keystrokes and mouse actions :\n"\
-	 "      q : quit\n",\
-	 "      w : switch to walk mode\n",\
-	 "      e : switch to examine mode\n",\
-	 "      h : toggle headlights on or off\n",\
-	 "      drag left mouse : rotate (examine mode) or translate\n",\
-	 "          (walk mode).\n",\
-	 "      drag right mouse : zoom (examine mode) or translate\n",\
-	 "          (walk mode).\n",\
+printf (["    Reminder of FreeWRL keystrokes and mouse actions :\n"...
+	 "      q : quit\n",...
+	 "      w : switch to walk mode\n",...
+	 "      e : switch to examine mode\n",...
+	 "      h : toggle headlights on or off\n",...
+	 "      drag left mouse : rotate (examine mode) or translate\n",...
+	 "          (walk mode).\n",...
+	 "      drag right mouse : zoom (examine mode) or translate\n",...
+	 "          (walk mode).\n",...
 	 "\n"]);
 
 ## Listing 1
