@@ -16,19 +16,19 @@
 printf("vrml_select_points does not work any more. Sorry\n");
 return
 
-printf (["\n",\
-	 "     VRML Mini-HOWTO's second listing\n",\
+printf (["\n",...
+	 "     VRML Mini-HOWTO's second listing\n",...
 	 "     Show 3D points and select some with the mouse\n\n"]);
 
-printf (["    Reminder of FreeWRL keystrokes and mouse actions :\n"\
-	 "      q : quit\n",\
-	 "      w : switch to walk mode\n",\
-	 "      e : switch to examine mode\n",\
-	 "      drag left mouse : rotate (examine mode) or translate\n",\
-	 "          (walk mode).\n",\
-	 "      drag right mouse : zoom (examine mode) or translate\n",\
-	 "          (walk mode).\n",\
-	 "      click on box : toggle selection\n",\
+printf (["    Reminder of FreeWRL keystrokes and mouse actions :\n"...
+	 "      q : quit\n",...
+	 "      w : switch to walk mode\n",...
+	 "      e : switch to examine mode\n",...
+	 "      drag left mouse : rotate (examine mode) or translate\n",...
+	 "          (walk mode).\n",...
+	 "      drag right mouse : zoom (examine mode) or translate\n",...
+	 "          (walk mode).\n",...
+	 "      click on box : toggle selection\n",...
 	 "\n"]);
 
 ## Listing 2
