@@ -153,11 +153,11 @@ function s = vrml_faces (x,f,varargin)
 
     texcoord_point_str = sprintf ("    %8.5f %8.5f\n", tcoord);
     
-    col_str_2 = sprintf (["  texCoord TextureCoordinate {\n",\
-			  "    point [\n      %s]\n",\
-			  "  }\n"\
-			  ],\
-			 texcoord_point_str\
+    col_str_2 = sprintf (["  texCoord TextureCoordinate {\n",...
+			  "    point [\n      %s]\n",...
+			  "  }\n"...
+			  ],...
+			 texcoord_point_str...
 			 );
     
 				# If texture has been provided
@@ -187,14 +187,14 @@ function s = vrml_faces (x,f,varargin)
       tcoord = tcoord (:,1:3*nfaces);
     end
 
-    col_str_2 = sprintf (["  texCoord TextureCoordinate {\n",\
-			  "    point [\n      %s]\n",\
-			  "  }\n",\
-			  "  texCoordIndex [\n      %s]\n",\
-			  "  coordIndex [\n      %s]\n",\
-			  ],\
-			 sprintf ("%10.8f %10.8f,\n      ",tcoord),\
-			 sprintf ("%-4d, %-4d, %-4d, -1,\n     ",0:3*nfaces-1),\
+    col_str_2 = sprintf (["  texCoord TextureCoordinate {\n",...
+			  "    point [\n      %s]\n",...
+			  "  }\n",...
+			  "  texCoordIndex [\n      %s]\n",...
+			  "  coordIndex [\n      %s]\n",...
+			  ],...
+			 sprintf ("%10.8f %10.8f,\n      ",tcoord),...
+			 sprintf ("%-4d, %-4d, %-4d, -1,\n     ",0:3*nfaces-1),...
 			 sprintf ("%-4d, %-4d, %-4d, -1,\n     ",f-1)
 			 );
     
@@ -205,7 +205,7 @@ function s = vrml_faces (x,f,varargin)
 				# surface
 
     col_str_1 = ["  appearance Appearance {\n",...
-		 vrml_material(col, emit, tran,DEFcol),\
+		 vrml_material(col, emit, tran,DEFcol),...
 		 "  }\n"];
 
     col_str_2 = "";
@@ -219,7 +219,7 @@ function s = vrml_faces (x,f,varargin)
       if tran, ts = sprintf ("transparency %8.3f",tran);
       else     ts = "";
       end
-      col_str_1 = ["appearance Appearance {\n",\
+      col_str_1 = ["appearance Appearance {\n",...
 		   "    material Material {",ts,"}\n}\n"];
     end
     if isnan (colorPerVertex)
@@ -229,13 +229,13 @@ function s = vrml_faces (x,f,varargin)
     end
     if colorPerVertex, cPVs = "TRUE"; else cPVs = "FALSE"; end
 
-    col_str_2 = sprintf (["     colorPerVertex %s\n",\
-			  "     color %s Color {\n",\
-			  "       color [\n%s\n",\
-			  "       ]\n",\
-			  "     }"],\
-			 cPVs,\
-			 col_def_str,\
+    col_str_2 = sprintf (["     colorPerVertex %s\n",...
+			  "     color %s Color {\n",...
+			  "       color [\n%s\n",...
+			  "       ]\n",...
+			  "     }"],...
+			 cPVs,...
+			 col_def_str,...
 			 sprintf("         %8.3f %8.3f %8.3f,\n",col));
   end
 
