@@ -65,12 +65,12 @@ if args
   verbose = 0;
 
   ## df = tars (col, hcol, diam, scale, verbose);
-  df = struct ("dc",     dc,    \ # Diameter of cone (absolute)
-	       "dr",     dr,    \ # Diameter of rod (absolute)
-	       "col",    col,   \ # Color
-	       "hcol",   hcol,  \ # Color of head (if different)
-	       "diam",   diam,  \ # Diameter of cone relative to branch length
-	       "scale",  scale, \ # Lenght of branches
+  df = struct ("dc",     dc,    ... # Diameter of cone (absolute)
+	       "dr",     dr,    ... # Diameter of rod (absolute)
+	       "col",    col,   ... # Color
+	       "hcol",   hcol,  ... # Color of head (if different)
+	       "diam",   diam,  ... # Diameter of cone relative to branch length
+	       "scale",  scale, ... # Lenght of branches
 	       "verbose",verbose);
   op1 = " col hcol diam scale dc dr ";
   op0 = " verbose ";
@@ -127,17 +127,17 @@ sz(4,:) ./= n;
 
 tmp = [r2(:,1), null(r2(:,1)')](:,[2,1,3])';
 if det (tmp) < 0, tmp(3,:) *= -1; end
-a1 = vrml_transfo (vrml_arrow(sz(:,1),[col(1,:);hcol(1,:)],0),\
+a1 = vrml_transfo (vrml_arrow(sz(:,1),[col(1,:);hcol(1,:)],0),...
 		   [0,0,0],tmp);
 ## keyboard
 tmp = [r2(:,2), null(r2(:,2)')](:,[2,1,3])';
 if det (tmp) < 0, tmp(3,:) *= -1; end
-a2 = vrml_transfo (vrml_arrow(sz(:,2),[col(2,:);hcol(2,:)],0),\
+a2 = vrml_transfo (vrml_arrow(sz(:,2),[col(2,:);hcol(2,:)],0),...
 		   [0,0,0],tmp);
 
 tmp = [r2(:,3), null(r2(:,3)')](:,[2,1,3])';
 if det (tmp) < 0, tmp(3,:) *= -1; end
-a3 = vrml_transfo (vrml_arrow(sz(:,3),[col(3,:);hcol(3,:)],0),\
+a3 = vrml_transfo (vrml_arrow(sz(:,3),[col(3,:);hcol(3,:)],0),...
 		   [0,0,0],tmp);
 
 f0 = vrml_group (a1, a2, a3);
