@@ -34,11 +34,11 @@ end
 ni = 4;
 s = [blanks(ni), strrep(s,"\n",["\n",blanks(ni)])(:)'];
 
-v = sprintf (["Group {\n",\
-              "  children [\n",\
-	      "%s",\
-              " ]\n",\
-	      "}\n"],\
+v = sprintf (["Group {\n",...
+              "  children [\n",...
+	      "%s",...
+              " ]\n",...
+	      "}\n"],...
 	     s);
 endfunction
 
