@@ -118,7 +118,7 @@ if numel (varargin)
   op1 = " tran col creaseAngle emit colorPerVertex checker DEFcoord DEFcol zcol bwid tex ";
   op0 = " smooth zgray zrb steps bars " ;
 
-  default = tars (tran, col, creaseAngle, emit, colorPerVertex, steps, bars, \
+  default = tars (tran, col, creaseAngle, emit, colorPerVertex, steps, bars, ...
 		  bwid, DEFcoord, DEFcol, zcol, smooth, checker, zgray, zrb, tex);
 
   s = read_options (varargin,"op0",op0,"op1",op1,"default",default);
@@ -374,7 +374,7 @@ if zgray || zrb || any (zcol(:)) # Treat zgray zrb and zcol options
   ii = find (ci >= columns (zcol));
   if ! isempty (ii), ci(ii) = columns (zcol) - 1; cw(ii) = 1; end
   col = zeros (3,R*C);
-  col(:,keepip) = \
+  col(:,keepip) = ...
       zcol(:,ci) .* ([1;1;1]*(1-cw)) + zcol(:,ci+1) .* ([1;1;1]*cw);
 
 end				# EOF zgray zrb and zcol options
@@ -419,8 +419,8 @@ if ! colorPerVertex
     col = reshape (col,3, (R-1)*(C-1));
     col = [col, col];
   else
-    printf(["vrml_surf : ",\
-	    " colorPerVertex==0, (R-1)*(C-1)==%i, but col has size [%i,%i]\n"],\
+    printf(["vrml_surf : ",...
+	    " colorPerVertex==0, (R-1)*(C-1)==%i, but col has size [%i,%i]\n"],...
      R*C,size (col));
   end
 
@@ -441,9 +441,9 @@ if ! all(keepp),
     keept = all (reshape(keepp(trgs),3,2*(R-1)*(C-1)));
   else
     tmp = reshape (keepp,R,C);
-    keept = \
-	all (reshape (tmp(trgs(1:2,:)),2,2*(R-1)*(C-1))) & \
-	[(tmp(1:R-1,2:C) | tmp(2:R,2:C))(:)', \
+    keept = ...
+	all (reshape (tmp(trgs(1:2,:)),2,2*(R-1)*(C-1))) & ...
+	[(tmp(1:R-1,2:C) | tmp(2:R,2:C))(:)', ...
 	 (tmp(1:R-1,1:C-1) | tmp(2:R,1:C-1))(:)'] ;
   end
 
@@ -473,10 +473,10 @@ if ! all(keepp),
 end
 ## printf ("Calling vrml_faces\n");
 if !tex
-  s = vrml_faces (pts, trgs, "col", col,\
-		  "colorPerVertex",colorPerVertex,\
-		  "creaseAngle", creaseAngle,\
-		  "tran", tran, "emit", emit,\
+  s = vrml_faces (pts, trgs, "col", col,...
+		  "colorPerVertex",colorPerVertex,...
+		  "creaseAngle", creaseAngle,...
+		  "tran", tran, "emit", emit,...
 		  "DEFcoord",DEFcoord,"DEFcol",DEFcol);
 else
    texXY = texXY(:,keepip);
@@ -488,8 +488,8 @@ else
 #  texXY(:,trgs(:))
 #   R, C
 #  keyboard
-  s = vrml_faces (pts, trgs,\
-		  "tran", tran, "tex", tex, "tcoord", texXY,\
+  s = vrml_faces (pts, trgs,...
+		  "tran", tran, "tex", tex, "tcoord", texXY,...
 		  "DEFcoord",DEFcoord,"DEFcol",DEFcol);
 end  
 ## printf ("Done\n");
