@@ -52,31 +52,31 @@ if nargin > 1
   style=     s.style;
   verbose=   s.verbose;
 end
-s = sprintf (["Shape {\n",\
-	      "  appearance Appearance {\n",\
-	      "    material Material {\n",\
-	      "      diffuseColor  %8.3f %8.3f %8.3f\n",\
-	      "      emissiveColor %8.3f %8.3f %8.3f\n",\
-	      "    }\n",\
-	      "  }\n",\
-	      "  geometry Text {\n",\
-	      "    string \"%s\"\n"\
-	      "    fontStyle FontStyle {\n",\
-	      "      family  \"%s\"\n",\
-	      "      justify \"%s\"\n",\
-	      "      style   \"%s\"\n",\
-	      "      size     %-8.3f\n",\
-	      "    }\n",\
-	      "  }\n",\
-	      "}\n",\
-	      ],\
-	     col,\
-	     col,\
-	     t,\
-	     family,\
-	     justify,\
-	     style,\
-	     size\
+s = sprintf (["Shape {\n",...
+	      "  appearance Appearance {\n",...
+	      "    material Material {\n",...
+	      "      diffuseColor  %8.3f %8.3f %8.3f\n",...
+	      "      emissiveColor %8.3f %8.3f %8.3f\n",...
+	      "    }\n",...
+	      "  }\n",...
+	      "  geometry Text {\n",...
+	      "    string \"%s\"\n"...
+	      "    fontStyle FontStyle {\n",...
+	      "      family  \"%s\"\n",...
+	      "      justify \"%s\"\n",...
+	      "      style   \"%s\"\n",...
+	      "      size     %-8.3f\n",...
+	      "    }\n",...
+	      "  }\n",...
+	      "}\n",...
+	      ],...
+	     col,...
+	     col,...
+	     t,...
+	     family,...
+	     justify,...
+	     style,...
+	     size...
 	     );
 
 endfunction
