@@ -75,8 +75,8 @@ else
   error ("vrml_transfo : rotation should have size 3x3, 3 or 4\n");
 end
 if verbose,
-  printf (["vrml_transfo : %8.3f %8.3f %8.3f %8.3f\n",\
-	   "               %8.3f %8.3f %8.3f\n"],\
+  printf (["vrml_transfo : %8.3f %8.3f %8.3f %8.3f\n",...
+	   "               %8.3f %8.3f %8.3f\n"],...
 	  axis,ang,t);
   printf ("length of string is %i\n",prod(size(s)));
 end
@@ -103,11 +103,11 @@ if any (abs (c - c0)>sqrt (eps))
 end
 if !isempty (DEF), sd = ["DEF ",DEF," "]; end 
 
-v = sprintf([sd,"Transform {\n",sr,st,ss,\
-	     "  children [\n%s\n",\
-	     "           ]\n",\
-	     "}\n",\
-	     ],\
+v = sprintf([sd,"Transform {\n",sr,st,ss,...
+	     "  children [\n%s\n",...
+	     "           ]\n",...
+	     "}\n",...
+	     ],...
 	    s) ;
 ## keyboard
 
